@@ -22,7 +22,7 @@ use File::Glob;
 use Hash::Util qw( lock_hashref unlock_hashref lock_ref_keys );
 use Fcntl qw( :flock );
 
-our $VERSION = '1.49';
+our $VERSION = '1.50';
 
 our @ISA    = qw( Exporter );
 our @EXPORT = qw(
@@ -121,6 +121,8 @@ our @EXPORT = qw(
               str_password_strength
               
               str_capitalize
+              
+              str_initials
 
               perl_package_to_file
 
@@ -759,13 +761,21 @@ sub str_password_strength
 }
 
 ##############################################################################
-# takes one SCALAR, returns first letter in upper case and lower case the rest
+# MISC string utils
 
+# takes one SCALAR, returns first letter in upper case and lower case the rest
 sub str_capitalize
 {
   return uc( substr( $_[0], 0, 1 ) ) . lc( substr( $_[0], 1 ) );
 }  
 
+# returns concatenated first letters of all words in the string
+# "James Webb Telescope" will return JWT
+sub str_initials
+{
+  return join '', $_[0] =~ /(\S)\S*/g;
+}
+
 ##############################################################################
 
 sub hash2str
@@ -860,7 +870,7 @@ sub __hash_ulc
   my $hr  = shift;
   my $uc  = shift;
   my $ipl = shift;
-  
+
   my $nr = $ipl ? $hr : {};
   for my $k ( keys %$hr )
     {
